summaryrefslogtreecommitdiffstats
path: root/kexi/kexidb/queryschemaparameter.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-25 05:28:35 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-25 05:28:35 +0000
commitf008adb5a77e094eaf6abf3fc0f36958e66896a5 (patch)
tree8e9244c4d4957c36be81e15b566b4aa5ea26c982 /kexi/kexidb/queryschemaparameter.h
parent1210f27b660efb7b37ff43ec68763e85a403471f (diff)
downloadkoffice-f008adb5a77e094eaf6abf3fc0f36958e66896a5.tar.gz
koffice-f008adb5a77e094eaf6abf3fc0f36958e66896a5.zip
TQt4 port koffice
This should enable compilation under both Qt3 and Qt4; fixes for any missed components will be forthcoming git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/koffice@1238284 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kexi/kexidb/queryschemaparameter.h')
-rw-r--r--kexi/kexidb/queryschemaparameter.h22
1 files changed, 11 insertions, 11 deletions
diff --git a/kexi/kexidb/queryschemaparameter.h b/kexi/kexidb/queryschemaparameter.h
index e7c00880..96168719 100644
--- a/kexi/kexidb/queryschemaparameter.h
+++ b/kexi/kexidb/queryschemaparameter.h
@@ -17,8 +17,8 @@
* Boston, MA 02110-1301, USA.
*/
-#ifndef KEXIDB_QUERYSCHEMAPARAMETER_H
-#define KEXIDB_QUERYSCHEMAPARAMETER_H
+#ifndef KEXIDB_TQUERYSCHEMAPARAMETER_H
+#define KEXIDB_TQUERYSCHEMAPARAMETER_H
#include "queryschema.h"
@@ -32,33 +32,33 @@ class KEXI_DB_EXPORT QuerySchemaParameter
QuerySchemaParameter();
~QuerySchemaParameter();
- QString debugString() const;
+ TQString debugString() const;
Field::Type type; //!< A datatype of the parameter
- QString message; //!< A user-visible message that will be displayed to ask for value of the parameter
+ TQString message; //!< A user-visible message that will be displayed to ask for value of the parameter
};
-typedef QValueList<QuerySchemaParameter> QuerySchemaParameterList;
-typedef QValueList<QuerySchemaParameter>::Iterator QuerySchemaParameterListIterator;
-typedef QValueList<QuerySchemaParameter>::ConstIterator QuerySchemaParameterListConstIterator;
+typedef TQValueList<QuerySchemaParameter> QuerySchemaParameterList;
+typedef TQValueList<QuerySchemaParameter>::Iterator QuerySchemaParameterListIterator;
+typedef TQValueList<QuerySchemaParameter>::ConstIterator QuerySchemaParameterListConstIterator;
//! Shows debug information for \a list
KEXI_DB_EXPORT void debug(const QuerySchemaParameterList& list);
//! @short An iteratof for a list of values of query schema parameters providing
//! Allows to iterate over parameters and return QVariant value or well-formatted string.
//! The iterator is initially set to the last item because of the parser requirements
class KEXI_DB_EXPORT QuerySchemaParameterValueListIterator
{
public:
- QuerySchemaParameterValueListIterator(const Driver& driver, const QValueList<QVariant>& params);
+ QuerySchemaParameterValueListIterator(const Driver& driver, const TQValueList<TQVariant>& params);
~QuerySchemaParameterValueListIterator();
//! \return previous value
- QVariant getPreviousValue();
+ TQVariant getPreviousValue();
//! \return previous value as string formatted using driver's escaping
- QString getPreviousValueAsString(Field::Type type);
+ TQString getPreviousValueAsString(Field::Type type);
protected:
class Private;
Private * const d;
@@ -32,33 +32,33 @@ class KEXI_DB_EXPORT QuerySchemaParameter
KEXI_DB_EXPORT void debug(const QuerySchemaParameterList& list);
//! @short An iteratof for a list of values of query schema parameters providing
-//! Allows to iterate over parameters and return QVariant value or well-formatted string.
+//! Allows to iterate over parameters and return TQVariant value or well-formatted string.
//! The iterator is initially set to the last item because of the parser requirements
class KEXI_DB_EXPORT QuerySchemaParameterValueListIterator